package org.ets.ibt.delivery.common;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;
import org.apache.commons.codec.binary.Base64;
import org.ets.ibt.delivery.admin.common.clep.PortalRequest;
import org.ets.ibt.delivery.admin.common.clep.PortalResponse;
import org.ets.ibt.delivery.cacheproxy.client.CacheProxyConfiguration;
import org.ets.ibt.delivery.common.ClepPortalServiceClientException;
import org.ets.ibt.delivery.common.JsonifyUtil;
import org.ets.ibt.delivery.server.utility.ServerProperties;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ClepPortalServiceClient {

   private static final Logger logger = LoggerFactory.getLogger(ClepPortalServiceClient.class);
   private String url;
   private String userId;
   private String passwd;


   public ClepPortalServiceClient(String url, String userId, String passwd) {
      this.url = url;
      this.userId = userId;
      this.passwd = passwd;
   }

   public PortalResponse makePortalRequest(PortalRequest request) throws Exception {
      logger.info("calling serverless url={} for ticket:{}, action:{}", new Object[]{this.url, request.getTicketID(), request.getActionString()});
      int retryCount = 0;

      while(true) {
         OutputStream os = null;
         HttpURLConnection conn = null;
         InputStream is = null;
         BufferedReader br = null;

         PortalResponse var12;
         try {
            conn = (HttpURLConnection)(new URL(this.url)).openConnection();
            conn.setDoOutput(true);
            conn.setRequestMethod("POST");
            conn.setRequestProperty("Content-Type", "application/json");
            conn.setRequestProperty("Accept", "application/json");
            boolean ex = true;
            boolean ex1 = true;
            int var25;
            int var26;
            if(request.isRequestFromCP()) {
               var25 = CacheProxyConfiguration.getClepServerLessServiceConnTimeout() * 1000;
               var26 = CacheProxyConfiguration.getClepServerLessServiceReadTimeout() * 1000;
            } else {
               var25 = ServerProperties.getClepServerLessServiceConnTimeout() * 1000;
               var26 = ServerProperties.getClepServerLessServiceReadTimeout() * 1000;
            }

            logger.info("Clep Portal call read timeout:{}, connect timeout:{}", Integer.valueOf(var26), Integer.valueOf(var25));
            conn.setConnectTimeout(var25);
            conn.setReadTimeout(var26);
            conn.setUseCaches(false);
            this.setUsernamePassword(conn, this.userId, this.passwd);
            String requestBody = JsonifyUtil.jsonify(request);
            os = conn.getOutputStream();
            os.write(requestBody.getBytes());
            os.flush();
            if(conn.getResponseCode() != 200) {
               logger.error(conn.getResponseCode());
               if(retryCount >= 3) {
                  throw new ClepPortalServiceClientException("Error calling the Clep webservice");
               }

               ++retryCount;
               continue;
            }

            is = conn.getInputStream();
            br = new BufferedReader(new InputStreamReader(is));
            String json = br.readLine();
            if(json == null) {
               throw new ClepPortalServiceClientException("Error calling clep service");
            }

            PortalResponse response = (PortalResponse)JsonifyUtil.unjsonify(json, PortalResponse.class);
            var12 = response;
         } catch (Exception var23) {
            logger.error("Error making clep portal call", var23);
            if(retryCount < 3) {
               ++retryCount;
               continue;
            }

            throw new ClepPortalServiceClientException("Error making clep portal call");
         } finally {
            try {
               if(br != null) {
                  br.close();
               }

               if(is != null) {
                  is.close();
               }

               if(os != null) {
                  os.close();
               }

               if(conn != null) {
                  conn.disconnect();
               }
            } catch (Exception var22) {
               logger.info("error in closing", var22);
            }

         }

         return var12;
      }
   }

   private URLConnection setUsernamePassword(URLConnection urlConnection, String username, String password) throws IOException {
      String authStringEnc = new String(Base64.encodeBase64(password.getBytes()));
      urlConnection.setRequestProperty("Authorization", authStringEnc);
      return urlConnection;
   }

   public static void main(String[] args) throws Exception {
   }

}
